@@ -2,7 +2,7 @@ package Importer;
 use strict qw/vars subs/; # Not refs!
 use warnings; no warnings 'once';
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 my %SIG_TO_SLOT = (
     '&' => 'CODE',
@@ -581,7 +581,7 @@ sub { *{"$into\\::\$_[0]"} = \$_[1] }
         my $new_name = join '' => ($spec->{'-prefix'} || '', $spec->{'-as'} || $name, $spec->{'-postfix'} || '');
 
         # Set the symbol (finally!)
-        $set_symbol->($new_name, $ref);
+        $set_symbol->($new_name, $ref, sig => $sig, symbol => $symbol, into => $into, from => $from, spec => $spec);
 
         # The remaining things get skipped with a custom setter
         next if $custom_set;
@@ -782,7 +782,7 @@ feature (like import renaming).
 =item $IMPORTER_VERSION (optional)
 
 If you provide a numeric argument as the first argument it will be treated as a
-version number. Importer will d a version check to make sure it is at least at
+version number. Importer will do a version check to make sure it is at least at
 the requested version.
 
 =item $FROM_MODULE (required)
@@ -814,6 +814,37 @@ implemented).
     $CARP{cluck}->("This will cluck");
     $CARP{croak}->("This will croak");
 
+The first two arguments to the custom sub are the name (no sigil), and the
+reference. The additional arguments are key/value pairs:
+
+    sub set_symbol {
+        my ($name, $ref, %info) = @_;
+    }
+
+=over 4
+
+=item $info{from}
+
+Package the symbol comes from.
+
+=item $info{into}
+
+Package to which the symbol should be added.
+
+=item $info{sig}
+
+The sigil that should be used.
+
+=item $info{spec}
+
+Extra details.
+
+=item $info{symbol}
+
+The original symbol name (with sigil) from the original package.
+
+=back
+
 =item @SYMBOLS (optional)
 
 Symbols you wish to import. If no symbols are specified then the defaults will
@@ -862,7 +893,7 @@ import name:
 You can also add a prefix and/or postfix:
 
     use Importer 'Some::Thing' => (
-        foo => { -prefix => 'my_foo' },
+        foo => { -prefix => 'my_' },
     );
 
 Using this syntax to set prefix and/or postfix also works on tags and patterns
@@ -1288,8 +1319,8 @@ the symbol table will occur.
 
 =head1 SOURCE
 
-The source code repository for symbol can be found at
-F<http://github.com/exodist/Importer>.
+The source code repository for Importer can be found at
+L<http://github.com/exodist/Importer>.
 
 =head1 MAINTAINERS
 
@@ -1314,6 +1345,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://dev.perl.org/licenses/>
+See L<http://dev.perl.org/licenses/>
 
 =cut
